==> oscars_mgmnt-0.1.50-py3-none-any.whl: oscars_mgmnt/parser/filename.py <==
from oscars_mgmnt.parser.base import BaseParser
from oscars_mgmnt.file_object import ObjectInfo


class WorldCoverParser(BaseParser):
    """ Parser used to transform ESA WorldCover filename to GeoJSON."""

    def __init__(self):
        super().__init__(template='WorldCover.template')

    def convert(self, product_file_info):

        import os
        import time

        # Initialize values dict
        values = {}

        # filename without extension
        file_name = os.path.basename(product_file_info.get_product_path()).split('.')[0]
        file_name_parts = file_name.split('_')

        year = file_name_parts[3]
        tile_id = file_name_parts[5]
        type = file_name_parts[6] # Map, S1VVVHratio or S2RGBNIR

        if type == 'Map':
            values['producttype'] = 'ESA_WORLDCOVER_10M'
            parent_identifier = 'urn:eop:VITO:ESA_WorldCover_10m_{0}_V1'.format(year)
            title = file_name.rsplit('_', 1)[0]
        elif type == 'S1VVVHratio':
            values['producttype'] = 'ESA_WORLDCOVER_S1VVVHratio_10M'
            parent_identifier = 'urn:eop:VITO:ESA_WorldCover_{0}_10m_{1}_V1'.format(type, year)
            title = file_name
        elif type == 'S2RGBNIR':
            values['producttype'] = 'ESA_WORLDCOVER_S2RGBNIR_10M'
            parent_identifier = 'urn:eop:VITO:ESA_WorldCover_{0}_10m_{1}_V1'.format(type, year)
            title = file_name
        else:
            raise Exception('Unsupported WorldCover type {O}'.format())

        bbox = self.get_bbox(tile_id, type)

        values['id'] = parent_identifier + ':' + title
        values['title'] = title
        values['parentidentifier'] = parent_identifier
        values['conformsto'] = 'https://www.opengis.net/def/crs/EPSG/0/4326'
        values['westbbox'] = bbox[0]
        values['southbbox'] = bbox[1]
        values['eastbbox'] = bbox[2]
        values['northbbox'] = bbox[3]
        values['tileid'] = tile_id
        values['resolution'] = 10

        values['beginposition'] = '{0}-01-01T00:00:00Z'.format(year)
        values['endposition'] = '{0}-12-31T23:59:59Z'.format(year)
        values['creationtime'] = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        values['catingestiondate'] = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        values['updatetime'] = time.strftime('%Y-%m-%dT%H:%M:%SZ',
                                             time.localtime(os.path.getmtime(product_file_info.get_product_path())))

        if self.jinja_template is None:
            self.with_template(self.template)

        specific_infos = self.splitted_treatment(product_file_info, values)

        # Generation of the output
        results = {}
        for specific in specific_infos:
            result = self.jinja_template.render(
                dict=specific.values,
                dirpath=specific.product_file_info.get_product_path(),
                products=specific.product_file_info.datas,
                previews=specific.product_file_info.previews,
                metadatas=specific.product_file_info.metadatas,
                related=specific.product_file_info.related
            )
            results[specific.uid] = result

        return results

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):

        for file_info_data in list(product_file_info.datas):
            if file_info_data.name.endswith('_Map.tif'):
                file_info_data.title = 'ESA_WORLDCOVER_10M_MAP'
            elif file_info_data.name.endswith('_InputQuality.tif'):
                file_info_data.title = 'ESA_WORLDCOVER_10M_INPUTQUALITY'
                file_info_data.category = 'QUALITY'
                product_file_info.datas.remove(file_info_data)
                product_file_info.related.append(file_info_data)
            elif file_info_data.name.endswith('_S2RGBNIR.tif'):
                file_info_data.title = 'S2RGBNIR'
            elif file_info_data.name.endswith('S1VVVHratio.tif'):
                file_info_data.title = 'S1VVVHratio'

        return values['id']

    @staticmethod
    def get_bbox(file_name_part, type):

        import re
        result = re.search('([N|S])(\d\d)([E|W])(\d\d\d)',
                           file_name_part)

        if type == 'Map':
            tile_size_degrees = 3
        else:
            tile_size_degrees = 1

        n_s = result.group(1)
        e_w = result.group(3)
        n_s_degrees = result.group(2)
        e_w_degrees = result.group(4)

        west_bbox = int(e_w_degrees) if e_w == 'E' else int(e_w_degrees) * -1
        east_bbox = west_bbox + tile_size_degrees
        south_bbox = int(n_s_degrees) if n_s == 'N' else int(n_s_degrees) * -1
        north_bbox = south_bbox + tile_size_degrees

        return [west_bbox, south_bbox, east_bbox, north_bbox]

==> oscars_mgmnt-0.1.58-py3-none-any.whl: oscars_mgmnt/parser/filename.py <==
from oscars_mgmnt.parser.base import BaseParser
from oscars_mgmnt.file_object import ObjectInfo


class WorldCoverParser(BaseParser):
    """ Parser used to transform ESA WorldCover filename to GeoJSON."""

    def __init__(self):
        super().__init__(template='WorldCover.template')

    def convert(self, product_file_info):

        import os
        import time

        # Initialize values dict
        values = {}

        # filename without extension
        file_name = os.path.basename(product_file_info.get_product_path()).split('.')[0]
        file_name_parts = file_name.split('_')

        year = file_name_parts[3]
        tile_id = file_name_parts[5]
        type = file_name_parts[6] # Map, S1VVVHratio or S2RGBNIR

        version = file_name_parts[4] # v100 or V200, ...
        major_version = int(version[1])

        if type == 'Map':
            values['producttype'] = 'ESA_WORLDCOVER_10M'
            parent_identifier = 'urn:eop:VITO:ESA_WorldCover_10m_{year}_V{major_version}'.format(
                year=year, major_version=major_version)
            title = file_name.rsplit('_', 1)[0]
        elif type == 'S1VVVHratio':
            values['producttype'] = 'ESA_WORLDCOVER_S1VVVHratio_10M'
            parent_identifier = 'urn:eop:VITO:ESA_WorldCover_{type}_10m_{year}_V{major_version}'.format(
                type=type, year=year, major_version=major_version)
            title = file_name
        elif type == 'S2RGBNIR':
            values['producttype'] = 'ESA_WORLDCOVER_S2RGBNIR_10M'
            parent_identifier = 'urn:eop:VITO:ESA_WorldCover_{type}_10m_{year}_V{major_version}'.format(
                type=type, year=year, major_version=major_version)
            title = file_name
        else:
            raise Exception('Unsupported WorldCover type {0}'.format(type))

        bbox = self.get_bbox(tile_id, type)

        values['id'] = parent_identifier + ':' + title
        values['title'] = title
        values['parentidentifier'] = parent_identifier
        values['conformsto'] = 'https://www.opengis.net/def/crs/EPSG/0/4326'
        values['westbbox'] = bbox[0]
        values['southbbox'] = bbox[1]
        values['eastbbox'] = bbox[2]
        values['northbbox'] = bbox[3]
        values['tileid'] = tile_id
        values['resolution'] = 10

        values['beginposition'] = '{0}-01-01T00:00:00Z'.format(year)
        values['endposition'] = '{0}-12-31T23:59:59Z'.format(year)
        values['creationtime'] = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        values['catingestiondate'] = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        values['updatetime'] = time.strftime('%Y-%m-%dT%H:%M:%SZ',
                                             time.localtime(os.path.getmtime(product_file_info.get_product_path())))

        if self.jinja_template is None:
            self.with_template(self.template)

        specific_infos = self.splitted_treatment(product_file_info, values)

        # Generation of the output
        results = {}
        for specific in specific_infos:
            result = self.jinja_template.render(
                dict=specific.values,
                dirpath=specific.product_file_info.get_product_path(),
                products=specific.product_file_info.datas,
                previews=specific.product_file_info.previews,
                metadatas=specific.product_file_info.metadatas,
                related=specific.product_file_info.related
            )
            results[specific.uid] = result

        return results

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):

        for file_info_data in list(product_file_info.datas):
            if file_info_data.name.endswith('_Map.tif'):
                file_info_data.title = 'ESA_WORLDCOVER_10M_MAP'
            elif file_info_data.name.endswith('_InputQuality.tif'):
                file_info_data.title = 'ESA_WORLDCOVER_10M_INPUTQUALITY'
                file_info_data.category = 'QUALITY'
                product_file_info.datas.remove(file_info_data)
                product_file_info.related.append(file_info_data)
            elif file_info_data.name.endswith('_S2RGBNIR.tif'):
                file_info_data.title = 'S2RGBNIR'
            elif file_info_data.name.endswith('S1VVVHratio.tif'):
                file_info_data.title = 'S1VVVHratio'

        return values['id']

    @staticmethod
    def get_bbox(file_name_part, type):

        import re
        result = re.search('([N|S])(\d\d)([E|W])(\d\d\d)',
                           file_name_part)

        if type == 'Map':
            tile_size_degrees = 3
        else:
            tile_size_degrees = 1

        n_s = result.group(1)
        e_w = result.group(3)
        n_s_degrees = result.group(2)
        e_w_degrees = result.group(4)

        west_bbox = int(e_w_degrees) if e_w == 'E' else int(e_w_degrees) * -1
        east_bbox = west_bbox + tile_size_degrees
        south_bbox = int(n_s_degrees) if n_s == 'N' else int(n_s_degrees) * -1
        north_bbox = south_bbox + tile_size_degrees

        return [west_bbox, south_bbox, east_bbox, north_bbox]
